PushSpaceNotifier class
- Inheritance
-
- Object
- ChangeNotifier
- PushSpaceNotifier
Constructors
Properties
- data ↔ SpaceData
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isListenerConnected → bool
-
no setter
- isMicOn → bool
-
no setter
- isSpeakerConnected → bool
-
no setter
- liveSpaceData → LiveSpaceData
-
no setter
-
pendingInvites
→ List<
String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacePlaybackUrl → String?
-
no setter
Methods
-
acceptPromotionInvite(
) → Future - Accepts a promotion invite for the current user to become a speaker in a live space.
-
acceptPromotionRequest(
{required String promoteeAddress}) → Future< void> - Promotion request is accepted by the host
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
initializeData(
{required String spaceId}) → Future< SpaceData?> -
inviteToPromote(
{required String inviteeAddress}) → dynamic -
Invites a listener ie
inviteeAddressto be promoted to a speaker. -
join(
{required String spaceId, String? address, String? pgpPrivateKey, Signer? signer, String? livepeerApiKey}) → Future< SpaceDTO?> -
leave(
) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onReceiveMetaMessage(
Map< String, dynamic> message) → dynamic -
rejectPromotionInvite(
) → Future - Rejects a promotion invite for the current user to become a speaker in a live space.
-
rejectPromotionRequest(
{required String promoteeAddress}) → dynamic - Promotion request is rejected by the host
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
requestToBePromoted(
) → dynamic - To be called by a listener and is requesting to be promoted as a speaker
-
sendReaction(
{required String reaction}) → dynamic -
setData(
SetDataFunction fn) → void -
setMicrophoneState(
bool isOn) → dynamic -
start(
{String? accountAddress, Signer? signer, required String spaceId, String? livepeerApiKey, required dynamic progressHook(ProgressHookType)}) → Future< SpaceDTO?> -
stop(
) → Future -
toggleMic(
) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
-
updateMeta(
{required String meta}) → dynamic
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited